@@ -105,6 +105,7 @@ LEDENET_REMOTE_CONFIG_RESPONSE_LEN = 14  # 2b 03 00 00 00 00 29 00 00 00 00 00 0
 LEDENET_TIME_RESPONSE_LEN = 12  # 10 14 16 01 02 10 26 20 07 00 0f a9
 LEDENET_TIMERS_8BYTE_RESPONSE_LEN = 88
 LEDENET_TIMERS_9BYTE_RESPONSE_LEN = 94
+LEDENET_TIMERS_SOCKET_RESPONSE_LEN = 100
 
 MSG_ORIGINAL_POWER_STATE = "original_power_state"
 MSG_ORIGINAL_STATE = "original_state"
@@ -2047,7 +2048,7 @@ class ProtocolLEDENETSocket(ProtocolLEDENET8Byte):
     @property
     def timer_response_len(self) -> int:
         """Return the time response len."""
-        return 100
+        return LEDENET_TIMERS_SOCKET_RESPONSE_LEN
 
     @property
     def timer_len(self) -> int:
@@ -2115,8 +2116,8 @@ class ProtocolLEDENETCCT(ProtocolLEDENET9Byte):
         b0 b1 b2 b3 00 01 01 72 00 09 35 b1 64 64 00 00 00 03 b1 a5 - 100% cool
         b0 b1 b2 b3 00 01 01 9f 00 09 35 b1 64 32 00 00 00 03 7f 6e - 100% cool - dim 50%
         """
-        assert warm_white is not None
-        assert cool_white is not None
+        assert warm_white is not None, "CCT devices must set a warm white value"
+        assert cool_white is not None, "CCT devices must set a cool white value"
         scaled_temp, brightness = white_levels_to_scaled_color_temp(
             warm_white, cool_white
         )
